@@ -93,17 +93,12 @@ class KnowledgeGraphCaller(CallerBase):
         出话kg知识库
         :param data: kg数据
         """
-        try:
-            response = requests.get(self.init_url)
-            if self._response_failed(response):
-                msg = "kg: 初始化数据失败：原因: 接口异常。" + str(response.json()) if response is not None else ''
-                raise BfEngineException(ErrorCode.kg_init_error, msg)
-        except BfEngineException as bfe:
-            raise bfe
-        except Exception:
-            msg = "kg: 初始化数据失败， 原因: Exception When POST '{}' : {}".format(self.init_url, traceback.format_exc())
+        response = requests.get(self.init_url)
+        if self._response_failed(response):
+            msg = "kg: 初始化数据失败：原因: 接口异常。" + str(response.json()) if response is not None else ''
             raise BfEngineException(ErrorCode.kg_init_error, msg)
 
+
     def load_data(self, data: dict):
         """
         加载json格式训练数据
