@@ -285,7 +285,7 @@ class QACaller(CallerBase):
             raise BfEngineException(code=code, msg=msg)
         for sq_data in resp["data"]:
             sq_data['id'] = str(sq_data['id'])
-            sq_data['category_id'] = str(sq_data['category_id'])
+            sq_data['category_id'] = str(sq_data.get('category_id'))
             for answer in sq_data['answers']:
                 answer['id'] = str(answer['id'])
                 answer['sq_id'] = str(answer['sq_id'])
@@ -430,7 +430,7 @@ class QACaller(CallerBase):
             raise BfEngineException(code=code, msg=msg)
         return True
 
-    def delete_corpus(self,corpus_id):
+    def delete_corpus(self, question_id, corpus_id):
         """
         删除语料
         :return:
@@ -440,6 +440,7 @@ class QACaller(CallerBase):
                 {
                     'lq_list': [
                         {
+                            'sq_id': int(question_id),
                             'id': int(corpus_id)
                         }
                     ]
