@@ -1,3 +1,4 @@
+from ..logger import log
 from .module import Module
 from ..caller.act_caller import DialogueActCaller
 
@@ -38,11 +39,14 @@ class DialogueAct(Module):
             self.init()
 
     def init(self):
-        act_code_map = {}
-        acts = self.get_acts()
-        for act in acts:
-            act_code_map[act.code] = act
-        self.act_code_map = act_code_map
+        try:
+            act_code_map = {}
+            acts = self.get_acts()
+            for act in acts:
+                act_code_map[act.code] = act
+            self.act_code_map = act_code_map
+        except Exception:
+            log.warning("act: fail to init")
 
     def predict(self, sentence: str, acts: list = None):
         """
