@@ -134,7 +134,10 @@ class KnowledgeGraph(Module):
             self.init()
 
     def init(self):
-        self.caller.init_data()
+        try:
+            self.caller.init_data()
+        except Exception:
+            log.warning('kg: fail to init')
 
     # 下面是 second version 增量训练
 
